clear
set mem 100m
set more off

  //////////////////////////////////////
 /*Cleans the master (merged) dataset*/
//////////////////////////////////////

use appended_preclean

/*Dropping unnecessary variables*/
drop pr1vote p1vote primaryvote
drop pr1 p1 primaryspent
drop  p2vote pr2vote
drop  pr2 p2
drop  occupation job
drop  gen generalspent
drop  candidate7 cand candidate
drop total totalspent
drop v8 v10 v12

/*Renames candidate variable*/
rename c candidate

/*Creating party variable and dummies*/
gen democrat=0
replace democrat=1 if party== "(D)i" | party== "ALO D" | party=="BP, D" | party=="D" | party=="D (wi)" | party=="D)ss" | party=="D, I, WF" | party=="D, IS" | party=="D, L" | party=="D,L" | party=="DFL" | party=="D-AN" | party=="D-I" | party=="D/LU" | party=="D/PFP" | party=="D?" | party=="NON, D"
gen republican=0
replace republican=1 if party=="(R)dev" | party=="IR" | party=="R" | party=="R (wi)" | party=="R, C" | party=="R,C, TCN" | party=="R,C,I" | party=="R-write in" | party=="R92)" | party=="R?" | party=="WI-R" | party=="RM"
gen third_party=1
replace third_party=0 if democrat==1 | republican==1
replace party="D" if democrat==1
replace party="R" if republican==1
replace party="3rd/Ind." if democrat==0 & republican==0

/*Renames the runnoff variables*/
rename runoff runoff_vote
rename v13 runoff_spend_nom

/*This cleans up the state variable*/
drop if state==""
replace state="IN" if state=="IND"
replace state="KY" if state=="KY*" | state=="Kentucky"
replace state="LA" if state=="Louisiana"
replace state="MS" if state=="Mississippi"
replace state="NJ" if state=="NEW JERSEY"
replace state="VA" if state=="VIRGINIA"
keep if state=="AK" | state=="AL" | state=="AR" | state=="AZ" | state=="CA" | state=="CO" | state=="CT" | state=="DE" | state=="FL" | state=="GA" | state=="HI" | state=="IA" | state=="ID" | state=="IL" | state=="IN" | state=="KS" | state=="KY" | state=="LA" | state=="MA" | state=="MD" | state=="ME" | state=="MI" | state=="MN" | state=="MO" | state=="MS" | state=="MT" | state=="NC" | state=="ND" | state=="NE" | state=="NH" | state=="NJ" | state=="NM" | state=="NV" | state=="NY" | state=="OH" | state=="OK" | state=="OR" | state=="PA" | state=="RI" | state=="SC" | state=="SD" | state=="TN" | state=="TX" | state=="UT" | state=="VA" | state=="VT" | state=="WA" | state=="WI" | state=="WV" | state=="WY"
format state %2s

/*Creates incumbent variables*/
gen incumbent=0
replace incumbent=1 if prev_occ=="I"
replace incumbent=1 if prev_occ=="i"
replace incumbent=1 if prev_occ=="ia"
replace incumbent=1 if prev_occ=="i,l"
replace incumbent=1 if prev_occ=="i,ine"
replace incumbent=1 if prev_occ=="i, rea"
replace incumbent=1 if prev_occ=="i, ph"
replace incumbent=1 if prev_occ=="i, law"
replace incumbent=1 if prev_occ=="i, l"
replace incumbent=1 if prev_occ=="i, j"
replace incumbent=1 if prev_occ=="i, fce (Pierce)"
replace incumbent=1 if prev_occ=="i, f"
replace incumbent=1 if prev_occ=="i, ed"
replace incumbent=1 if prev_occ=="i, bdc"
replace incumbent=1 if prev_occ=="i (did not run)"
replace incumbent=0 if year==1990 & state=="AR" & (candidate=="Sheffield Nelson" | candidate=="Joe Holmes" | candidate=="Tom McRae")
replace incumbent=0 if year==1990 & state=="HI" & candidate=="Benjamin Hopkins"


/*Creates a public finance variable*/
gen pubfnc=0
replace pubfnc=1 if state=="MD" | state=="MI" | state=="MN" | state=="NJ" | state=="RI" | state=="WI"
replace pubfnc=1 if state=="AZ" & year>=2002
replace pubfnc=1 if state=="FL" & year>=1990
replace pubfnc=1 if state=="HI" & year>=1982
replace pubfnc=1 if state=="KY" & year>=1995 & year<=1999
replace pubfnc=1 if state=="MA" & year>=2002
replace pubfnc=1 if state=="ME" & year>=2002
replace pubfnc=1 if state=="MT" & year<=1992
replace pubfnc=1 if state=="NE" & year>=1994
replace pubfnc=1 if state=="VT" & year>=1998

/*Some of the raw data is incorrect. I fix it here. I cross-reference with CQ guide to 
US Elections, 4th ed. Ch31 for accuracy.*/
replace party="D" if year==1998 & state=="WI" & candidate=="Gary R. George"
replace democrat=1 if year==1998 & state=="WI" & candidate=="Gary R. George"
replace republican=0 if year==1998 & state=="WI" & candidate=="Gary R. George"
replace primary_vote=100 if year==1986 & state=="SC" & candidate=="Carroll A. Campbell"
replace primary_vote=0 if year==1996 & state=="UT" & candidate=="Gene-Metzger-Agin"
replace total_spend=runoff_vote if year==1991 & state=="LA"
replace runoff_vote=. if year==1991 & state=="LA"

/*Generate a real spending variable*/
replace total_spend=1080263 if year==1998 & state=="NH" & candidate=="Jeanne Shaheen"
replace total_spend=1538912 if year==1998 & state=="NH" & candidate=="Jay Lucas"
foreach i in primary_spend primary_spend_r general_spend runoff_spend total_spend{
foreach j in ln _{
gen `j'`i'_real=0
}
replace _`i'_real=`i'_nom/ 0.282468758302764 if year==1977
replace _`i'_real=`i'_nom/ 0.303910281210234 if year==1978
replace _`i'_real=`i'_nom/ 0.338403165887469 if year==1979
replace _`i'_real=`i'_nom/ 0.384082932081646 if year==1980
replace _`i'_real=`i'_nom/ 0.423703137454145 if year==1981
replace _`i'_real=`i'_nom/ 0.449805860993675 if year==1982
replace _`i'_real=`i'_nom/ 0.464255582953057 if year==1983
replace _`i'_real=`i'_nom/ 0.48429874567091 if year==1984
replace _`i'_real=`i'_nom/ 0.501545188009527 if year==1985
replace _`i'_real=`i'_nom/ 0.510867589273645 if year==1986
replace _`i'_real=`i'_nom/ 0.52951239180188 if year==1987
replace _`i'_real=`i'_nom/ 0.551420034772557 if year==1988
replace _`i'_real=`i'_nom/ 0.577988878375292 if year==1989
replace _`i'_real=`i'_nom/ 0.609218922610086 if year==1990
replace _`i'_real=`i'_nom/ 0.634855526086409 if year==1991
replace _`i'_real=`i'_nom/ 0.65396644867785 if year==1992
replace _`i'_real=`i'_nom/ 0.673543491332497 if year==1993
replace _`i'_real=`i'_nom/ 0.690789933671115 if year==1994
replace _`i'_real=`i'_nom/ 0.710366976325762 if year==1995
replace _`i'_real=`i'_nom/ 0.731342379170027 if year==1996
replace _`i'_real=`i'_nom/ 0.748122701445438 if year==1997
replace _`i'_real=`i'_nom/ 0.759775703025585 if year==1998
replace _`i'_real=`i'_nom/ 0.776556025300997 if year==1999
replace _`i'_real=`i'_nom/ 0.802658748840526 if year==2000
replace _`i'_real=`i'_nom/ 0.825498631937614 if year==2001
replace _`i'_real=`i'_nom/ 0.838549993707379 if year==2002
replace _`i'_real=`i'_nom/ 0.85766091629882 if year==2003
replace _`i'_real=`i'_nom/ 0.880500799395908 if year==2004
replace _`i'_real=`i'_nom/ 0.910332483441085 if year==2005
replace _`i'_real=`i'_nom/ 0.939698047423055 if year==2006
replace _`i'_real=`i'_nom/ 0.966462661452337 if year==2007
replace _`i'_real=`i'_nom/ 1.00357047968416 if year==2008
replace _`i'_real=`i'_nom/ 1 if year==2009
replace ln`i'_real=ln(_`i'_real+1)
}

/*Creates a female dummy variable*/
gen female=.
replace  female=1  if year==1982  & state=="IA"  & candidate=="Roxanne Conlin"   
replace  female=1  if year==1982  & state=="VT"  & candidate=="Madeleine Kunin"   
replace  female=1  if year==1983  & state=="KY"  & candidate=="Martha Lane Collins"  
replace  female=1  if year==1984  & state=="VT"  & candidate=="Madeleine Kunin"   
replace  female=1  if year==1986  & state=="AK"  & candidate=="Arliss Sturgulewski (with Terry Miller-LG)"
replace  female=1  if year==1986  & state=="AZ"  & candidate=="Carolyn Warner"   
replace  female=1  if year==1986  & state=="CT"  & candidate=="Julie D. Belaga"  
replace  female=1  if year==1986  & state=="NE"  & candidate=="Kay A. Orr"  
replace  female=1  if year==1986  & state=="NE"  & candidate=="Helen Boosalis"   
replace  female=1  if year==1986  & state=="NV"  & candidate=="Patty Cafferata"   
replace  female=1  if year==1986  & state=="OR"  & candidate=="Norma Paulus"   
replace  female=1  if year==1986  & state=="VT"  & candidate=="Madeleine M. Kunin (D)i" 
replace  female=1  if year==1988  & state=="MO"  & candidate=="Betty C. Hearnes"  
replace  female=1  if year==1988  & state=="VT"  & candidate=="Madeleine Kunin"   
replace  female=1  if year==1990  & state=="AK"  & candidate=="Arliss Sturgulewski"   
replace  female=1  if year==1990  & state=="CA"  & candidate=="Dianne Feinstein"   
replace  female=1  if year==1990  & state=="KS"  & candidate=="Joan Finney"   
replace  female=1  if year==1990  & state=="NE"  & candidate=="Kay Orr"   
replace  female=1  if year==1990  & state=="OR"  & candidate=="Barbara Roberts"   
replace  female=1  if year==1990  & state=="PA"  & candidate=="Barbara Hafer"   
replace  female=1  if year==1990  & state=="TX"  & candidate=="Ann Richards"   
replace  female=1  if year==1990  & state=="WY"  & candidate=="Mary Mead"   
replace  female=1  if year==1992  & state=="MT"  & candidate=="Dorothy Bradley"   
replace  female=1  if year==1992  & state=="NH"  & candidate=="Deborah Arnie Arnesen"  
replace  female=1  if year==1992  & state=="RI"  & candidate=="Elizabeth Anne Leonard"  
replace  female=1  if year==1993  & state=="NJ"  & candidate=="Christine T. Whitman"  
replace  female=1  if year==1993  & state=="VA"  & candidate=="Mary Sue Terry"  
replace  female=1  if year==1994  & state=="CA"  & candidate=="Kathleen Brown"   
replace  female=1  if year==1994  & state=="CT"  & candidate=="Eunace Groark"   
replace  female=1  if year==1994  & state=="HI"  & candidate=="Patricia Saiki"   
replace  female=1  if year==1994  & state=="IA"  & candidate=="Bonnie Campbell"   
replace  female=1  if year==1994  & state=="IL"  & candidate=="Dawn Clark Netsch"  
replace  female=1  if year==1994  & state=="MD"  & candidate=="Ellen Sauerbrey"   
replace  female=1  if year==1994  & state=="ME"  & candidate=="Susan M. Collins"  
replace  female=1  if year==1994  & state=="RI"  & candidate=="Myrth York"   
replace  female=1  if year==1994  & state=="TX"  & candidate=="Ann Richards"   
replace  female=1  if year==1994  & state=="WY"  & candidate=="Kathy Karpan"   
replace  female=1  if year==1996  & state=="DE"  & candidate=="Janet C. Rzewnicki"  
replace  female=1  if year==1996  & state=="MO"  & candidate=="Margaret Kelly"   
replace  female=1  if year==1996  & state=="MT"  & candidate=="Judy Jacobson"   
replace  female=1  if year==1996  & state=="NH"  & candidate=="Jeanne Shaheen"   
replace  female=1  if year==1996  & state=="WA"  & candidate=="Ellen Craswell"   
replace  female=1  if year==1996  & state=="WV"  & candidate=="Charlotte Pritt"   
replace  female=1  if year==1997  & state=="NJ"  & candidate=="Christine T. Whitman"  
replace  female=1  if year==1998  & state=="AZ"  & candidate=="Jane Dee Hull"  
replace  female=1  if year==1998  & state=="CO"  & candidate=="Gail Schoettler"   
replace  female=1  if year==1998  & state=="CT"  & candidate=="Barbara Kennelly"   
replace  female=1  if year==1998  & state=="HI"  & candidate=="Linda Lingle"   
replace  female=1  if year==1998  & state=="MD"  & candidate=="Ellen Sauerbrey"   
replace  female=1  if year==1998  & state=="NH"  & candidate=="Jeanne Shaheen"   
replace  female=1  if year==1998  & state=="NV"  & candidate=="Jan Laverty Jones"  
replace  female=1  if year==1998  & state=="OK"  & candidate=="Laura Boyd"   
replace  female=1  if year==1998  & state=="RI"  & candidate=="Myrth York"   
replace  female=1  if year==1998  & state=="VT"  & candidate=="Ruth Dwyer"   
replace  female=1  if year==1999  & state=="KY"  & candidate=="Peppy Martin"   
replace  female=1  if year==2000  & state=="DE"  & candidate=="Ruth Ann Minner"  
replace  female=1  if year==2000  & state=="MT"  & candidate=="Judy Martz"   
replace  female=1  if year==2000  & state=="ND"  & candidate=="Heidi Heitkamp, D ag" 
replace  female=1  if year==2000  & state=="NH"  & candidate=="Jeanne Shaheen"   
replace  female=1  if year==2000  & state=="VT"  & candidate=="Ruth Dwyer"   
replace  female=1  if year==2002  & state=="AK"  & candidate=="Fran Ulmer"   
replace  female=1  if year==2002  & state=="AR"  & candidate=="Jimmy Lou Fisher"  
replace  female=1  if year==2002  & state=="AZ"  & candidate=="Janet Napolitano"   
replace  female=1  if year==2002  & state=="HI"  & candidate=="Linda Lingle"   
replace  female=1  if year==2002  & state=="HI"  & candidate=="Mazie Hirono"   
replace  female=1  if year==2002  & state=="KS"  & candidate=="Kathleen Sebelius"   
replace  female=1  if year==2002  & state=="MA"  & candidate=="Shannon O'Brien"   
replace  female=1  if year==2002  & state=="MD"  & candidate=="Kathleen Kennedy Townsend"  
replace  female=1  if year==2002  & state=="MI"  & candidate=="Jennifer Granholm"   
replace  female=1  if year==2002  & state=="RI"  & candidate=="Myrth York"   
replace  female=1  if year==2004  & state=="DE"  & candidate=="Ruth Ann Minner"  
replace  female=1  if year==2004  & state=="MO"  & candidate=="Claire McCaskill"   
replace  female=1  if year==2004  & state=="WA"  & candidate=="Christine Gregoire"   
replace  female=1  if year==2006  & state=="AK"  & candidate=="Sarah Palin"   
replace  female=1  if year==2006  & state=="AL"  & candidate=="Lucy Baxley"   
replace  female=1  if year==2006  & state=="AZ"  & candidate=="Janet Napolitano"   
replace  female=1  if year==2006  & state=="CT"  & candidate=="M. Jodi Rell, R i"
replace  female=1  if year==2006  & state=="HI"  & candidate=="Linda Lingle"   
replace  female=1  if year==2006  & state=="IL"  & candidate=="Judy B. Topinka"  
replace  female=1  if year==2006  & state=="KS"  & candidate=="Kathleen Sebelius"   
replace  female=1  if year==2006  & state=="MA"  & candidate=="Kerry Healy"   
replace  female=1  if year==2006  & state=="MI"  & candidate=="Jennifer Granholm"   
replace  female=1  if year==2006  & state=="NV"  & candidate=="Dina Titus"   
replace  female=1  if year==2008  & state=="IN"  & candidate=="Jill Long Thompson"  
replace  female=1  if year==2008  & state=="NC"  & candidate=="Beverly Perdue"   
replace  female=1  if year==2008  & state=="VT"  & candidate=="Gaye Symington"   
replace  female=1  if year==2008  & state=="WA"  & candidate=="Christine Gregoire"   
replace female=-9 if year== 1994 & state=="FL" & candidate==" Arnold"
replace female=-9 if year== 1990 & state=="OK" & candidate==" Barnett"
replace female=-9 if year== 2003 & state=="LA" & candidate==" Barthel"
replace female=-9 if year== 1988 & state=="MT" & candidate==" Beckman"
replace female=-9 if year== 2003 & state=="LA" & candidate==" Blossman, Jr."
replace female=-9 if year== 1999 & state=="LA" & candidate==" Bush"
replace female=-9 if year== 2002 & state=="VT" & candidate=="' Christian"
replace female=-9 if year== 1996 & state=="WV" & candidate==" Davis"
replace female=-9 if year== 2003 & state=="LA" & candidate==" Estilette"
replace female=-9 if year== 1982 & state=="NV" & candidate==" Eyre, Jr"
replace female=-9 if year== 1982 & state=="AL" & candidate==" Folsom"
replace female=-9 if year== 2004 & state=="WV" & candidate==" Frye*"
replace female=-9 if year== 2007 & state=="KY" & candidate==" Hensley"
replace female=-9 if year== 1992 & state=="VT" & candidate==" Jaccaci"
replace female=-9 if year== 2003 & state=="LA" & candidate==" Landry"
replace female=-9 if year== 1996 & state=="VT" & candidate==" Lane"
replace female=-9 if year== 2003 & state=="LA" & candidate==" Leach"
replace female=-9 if year== 1998 & state=="NY" & candidate==" Lewis"
replace female=-9 if year== 1986 & state=="OK" & candidate==" Little"
replace female=-9 if year== 2003 & state=="LA" & candidate==" Mangin"
replace female=-9 if year== 1994 & state=="FL" & candidate==" Martin"
replace female=-9 if year== 1995 & state=="KY" & candidate==" Maynard"
replace female=-9 if year== 2007 & state=="LA" & candidate==" Mendoza"
replace female=-9 if year== 1986 & state=="FL" & candidate==" Myers"
replace female=-9 if year== 2008 & state=="UT" & candidate==" Nafoosi -- eliminated in"
replace female=-9 if year== 2007 & state=="LA" & candidate==" Nichols"
replace female=-9 if year== 2004 & state=="WV" & candidate==" Railey"
replace female=-9 if year== 2003 & state=="LA" & candidate==" Simoneaux, Jr."
replace female=-9 if year== 2008 & state=="UT" & candidate==" Smith -- eliminated in"
replace female=-9 if year== 1986 & state=="NV" & candidate==" Stover"
replace female=-9 if year== 1988 & state=="MT" & candidate==" Thornton"
replace female=-9 if year== 2002 & state=="AL" & candidate==" Townsend"
replace female=-9 if year== 1982 & state=="CA" & candidate==" Trevino"
replace female=-9 if year== 1990 & state=="GA" & candidate==" Veazey"
replace female=-9 if year== 1999 & state=="LA" & candidate==" Ward"
replace female=-9 if year== 1982 & state=="TX" & candidate==" Willis"
replace female=-9 if year== 1990 & state=="AR" & candidate==" Wilson"
replace female=-9 if year== 1978 & state=="CA" & candidate=="Alex Alioe"
replace female=-9 if year== 1978 & state=="KS" & candidate=="Berry Beets"
replace female=-9 if year== 2001 & state=="NJ" & candidate=="Constantine Rozzo"
replace female=-9 if year== 2006 & state=="NM" & candidate=="Denish -- write-in"
replace female=-9 if year== 1984 & state=="WV" & candidate=="E.E. Cumpton"
replace female=-9 if year== 1982 & state=="MN" & candidate=="E.W. Peterson"
replace female=-9 if year== 1978 & state=="AL" & candidate=="F.C. Koster"
replace female=-9 if year== 1982 & state=="ID" & candidate=="Fisher"
replace female=-9 if year== 1982 & state=="FL" & candidate=="Geison"
replace female=-9 if year== 1995 & state=="LA" & candidate=="Gene Alexander"
replace female=-9 if year== 1978 & state=="AZ" & candidate=="Gene Lewteris"
replace female=-9 if year== 2002 & state=="AZ" & candidate=="Gnant for Governor"
replace female=-9 if year== 1984 & state=="NC" & candidate=="H. Fritz Prochow"
replace female=-9 if year== 1998 & state=="IA" & candidate=="Hughes"
replace female=-9 if year== 1986 & state=="TX" & candidate=="J. Muriel"
replace female=-9 if year== 1984 & state=="NC" & candidate=="J.A. Barker"
replace female=-9 if year== 1978 & state=="TN" & candidate=="Jesse McDonald"
replace female=-9 if year== 2002 & state=="TN" & candidate=="Jessie McDonald"
replace female=-9 if year== 1978 & state=="WY" & candidate=="Jime Bace"
replace female=-9 if year== 1978 & state=="CA" & candidate=="Jules Kimmett"
replace female=-9 if year== 1982 & state=="CA" & candidate=="Jules Kimmett"
replace female=-9 if year== 2006 & state=="NH" & candidate=="Kahn (write-in)"
replace female=-9 if year== 1998 & state=="AL" & candidate=="Lee Lamb"
replace female=-9 if year== 2002 & state=="OR" & candidate=="Lee Shindler"
replace female=-9 if year== 1994 & state=="KS" & candidate=="Lellie Kitchenmaster"
replace female=-9 if year== 2006 & state=="IA" & candidate=="Litten"
replace female=-9 if year== 1983 & state=="MS" & candidate=="Lonnie C. Johnson"
replace female=-9 if year== 1995 & state=="LA" & candidate=="Lonnie Creech"
replace female=-9 if year== 1998 & state=="TN" & candidate=="Lonnie Creech"
replace female=-9 if year== 2006 & state=="IA" & candidate=="Martin"
replace female=-9 if year== 1983 & state=="LA" & candidate=="Midiele Smith"
replace female=-9 if year== 1978 & state=="TN" & candidate=="Miller"
replace female=-9 if year== 1998 & state=="IA" & candidate=="Moses"
replace female=-9 if year== 2008 & state=="NH" & candidate=="Newell"
replace female=-9 if year== 1994 & state=="KS" & candidate=="R. Trackwell"
replace female=-9 if year== 1980 & state=="WA" & candidate=="Rabbine Sutich"
replace female=-9 if year== 2002 & state=="ID" & candidate=="Raynelle J. George"
replace female=-9 if year== 1978 & state=="MN" & candidate=="Robin Miller"
replace female=-9 if year== 2006 & state=="MA" & candidate=="Ross"
replace female=-9 if year== 1978 & state=="CO" & candidate=="Sal Mandor"
replace female=-9 if year== 1994 & state=="WY" & candidate=="Seaghan Uibreasain"
replace female=-9 if year== 1978 & state=="TN" & candidate=="Shelley Stiles"
replace female=-9 if year== 1986 & state=="FL" & candidate=="Sol Roth"
replace female=-9 if year== 1990 & state=="TN" & candidate=="Terry A. Williams"
replace female=-9 if year== 1990 & state=="OR" & candidate=="Terry Hutchison"
replace female=-9 if year== 1998 & state=="NV" & candidate=="Terry Savage"
replace female=-9 if year== 2002 & state=="MI" & candidate=="Tracey Stevenson"
replace female=-9 if year== 2002 & state=="HI" & candidate=="Tracy Ahn Ryan"
replace female=-9 if year== 2002 & state=="AZ" & candidate=="Tracy Sturgess (write-in)"
replace female=-9 if year== 1978 & state=="CA" & candidate=="TRUE Slocum, Jr."
replace female=-9 if year== 1982 & state=="IL" & candidate=="V.A. Kelley"
replace female=1 if year== 1990 & state=="GA" & candidate==" McDonald"
replace female=1 if year== 1986 & state=="SD" & candidate=="Alice Kundert"
replace female=1 if year== 1978 & state=="MN" & candidate=="Alice Tripp"
replace female=1 if year== 1998 & state=="VT" & candidate=="Amy Berkey"
replace female=1 if year== 1992 & state=="MT" & candidate=="Andrea Bennett"
replace female=1 if year== 2005 & state=="NJ" & candidate=="Angela Lariscy"
replace female=1 if year== 1994 & state=="AL" & candidate=="Ann Bedsole"
replace female=1 if year== 1981 & state=="NJ" & candidate=="Ann Klein"
replace female=1 if year== 1990 & state=="TX" & candidate=="Ann Richards"
replace female=1 if year== 1994 & state=="TX" & candidate=="Ann Richards"
replace female=1 if year== 1995 & state=="LA" & candidate=="Ann Thompson"
replace female=1 if year== 1982 & state=="TN" & candidate=="Anna Bell Clement O'Brien"
replace female=1 if year== 1984 & state=="ND" & candidate=="Anna Belle Bourgois"
replace female=1 if year== 1990 & state=="OK" & candidate=="Anne Hartin Langston"
replace female=1 if year== 1987 & state=="KY" & candidate=="Anne Moore"
replace female=1 if year== 2007 & state=="KY" & candidate=="Anne Northrup"
replace female=1 if year== 2007 & state=="LA" & candidate=="B. Alexandrenko"
replace female=1 if year== 1988 & state=="WA" & candidate=="Baba Jeanne Mangaoang"
replace female=1 if year== 1978 & state=="MA" & candidate=="Barbara Ackermann"
replace female=1 if year== 1994 & state=="AZ" & candidate=="Barbara Barrett"
replace female=1 if year== 2006 & state=="CA" & candidate=="Barbara Becnel"
replace female=1 if year== 1989 & state=="NJ" & candidate=="Barbara Boggs Sigmund"
replace female=1 if year== 1986 & state=="AL" & candidate=="Barbara Evans O'Neil"
replace female=1 if year== 1990 & state=="PA" & candidate=="Barbara Hafer"
replace female=1 if year== 2000 & state=="NC" & candidate=="Barbara Howe"
replace female=1 if year== 2004 & state=="NC" & candidate=="Barbara Howe"
replace female=1 if year== 2002 & state=="MA" & candidate=="Barbara Jackson"
replace female=1 if year== 1998 & state=="CT" & candidate=="Barbara Kennelly"
replace female=1 if year== 1981 & state=="NJ" & candidate=="Barbara McConnell"
replace female=1 if year== 2006 & state=="ME" & candidate=="Barbara Merrill"
replace female=1 if year== 1986 & state=="KS" & candidate=="Barbara Pomeroy"
replace female=1 if year== 1990 & state=="OR" & candidate=="Barbara Roberts"
replace female=1 if year== 1998 & state=="NV" & candidate=="Barbara Scott"
replace female=1 if year== 2002 & state=="NV" & candidate=="Barbara Scott"
replace female=1 if year== 1982 & state=="IL" & candidate=="Bea Armstrong"
replace female=1 if year== 1986 & state=="MN" & candidate=="Beatrice J. Mooney"
replace female=1 if year== 1990 & state=="MN" & candidate=="Beatrice Mooney"
replace female=1 if year== 2006 & state=="MN" & candidate=="Becky Lourey"
replace female=1 if year== 1995 & state=="LA" & candidate=="Belinda Alexandrenko"
replace female=1 if year== 1999 & state=="LA" & candidate=="Belinda Alexandrenko"
replace female=1 if year== 1994 & state=="OK" & candidate=="Bernice Shedrick"
replace female=1 if year== 1998 & state=="SD" & candidate=="Bernie Hunoff"
replace female=1 if year== 2002 & state=="AZ" & candidate=="Betsey Bayless"
replace female=1 if year== 1998 & state=="NY" & candidate=="Betsy McGaughey Ross D, L"
replace female=1 if year== 1988 & state=="MO" & candidate=="Betty C. Hearnes"
replace female=1 if year== 1986 & state=="OR" & candidate=="Betty Freauf (R)ina"
replace female=1 if year== 2002 & state=="NH" & candidate=="Bev Hollingsworth"
replace female=1 if year== 2008 & state=="NC" & candidate=="Beverly Perdue"
replace female=1 if year== 2002 & state=="OR" & candidate=="Beverly Stein, D fcoc (Multnomah)"
replace female=1 if year== 1994 & state=="IA" & candidate=="Bonnie Campbell"
replace female=1 if year== 2002 & state=="MA" & candidate=="Carla Howell"
replace female=1 if year== 1990 & state=="GA" & candidate=="Carol Ann Rand"
replace female=1 if year== 2006 & state=="FL" & candidate=="Carol Castagnero"
replace female=1 if year== 2002 & state=="AZ" & candidate=="Carol Springer"
replace female=1 if year== 1980 & state=="WA" & candidate=="Caroline (Hope) Diamond"
replace female=1 if year== 2006 & state=="TX" & candidate=="Carolyn K. Strayhorn, I sa"
replace female=1 if year== 1986 & state=="AZ" & candidate=="Carolyn Warner"
replace female=1 if year== 1994 & state=="PA" & candidate=="Catherine B. Knoll"
replace female=1 if year== 2003 & state=="MS" & candidate=="Catherine Starr"
replace female=1 if year== 2006 & state=="GA" & candidate=="Cathy Cox"
replace female=1 if year== 1992 & state=="WV" & candidate=="Charlotte Pritt"
replace female=1 if year== 1996 & state=="WV" & candidate=="Charlotte Pritt"
replace female=1 if year== 1982 & state=="NV" & candidate=="Cher Volin"
replace female=1 if year== 1994 & state=="NV" & candidate=="Cheryl A. Lau"
replace female=1 if year== 1984 & state=="WA" & candidate=="Cheryll Hidelgo"
replace female=1 if year== 2002 & state=="VT" & candidate=="Chris Erickson"
replace female=1 if year== 2004 & state=="VT" & candidate=="Chris Ericson"
replace female=1 if year== 2008 & state=="VT" & candidate=="Chris Ericson"
replace female=1 if year== 1990 & state=="KS" & candidate=="Christina Campbell-Cline"
replace female=1 if year== 2006 & state=="NM" & candidate=="Christina Vahlsing"
replace female=1 if year== 2004 & state=="WA" & candidate=="Christine Gregoire"
replace female=1 if year== 2008 & state=="WA" & candidate=="Christine Gregoire"
replace female=1 if year== 1993 & state=="NJ" & candidate=="Christine T. Whitman"
replace female=1 if year== 1997 & state=="NJ" & candidate=="Christine T. Whitman"
replace female=1 if year== 2004 & state=="MO" & candidate=="Claire McCaskill"
replace female=1 if year== 1986 & state=="MI" & candidate=="Colleen Engler"
replace female=1 if year== 2002 & state=="IL" & candidate=="Corinne Wood"
replace female=1 if year== 2006 & state=="VT" & candidate=="Cris Ericson"
replace female=1 if year== 2002 & state=="HI" & candidate=="Crystal Young"
replace female=1 if year== 1994 & state=="IL" & candidate=="Dawn Clark Netsch"
replace female=1 if year== 2002 & state=="AK" & candidate=="Dawn M. Mendias"
replace female=1 if year== 2006 & state=="CO" & candidate=="Dawn Winkler"
replace female=1 if year== 1994 & state=="MI" & candidate=="Debbie Stabenow"
replace female=1 if year== 1992 & state=="NH" & candidate=="Deborah Arnie Arnesen"
replace female=1 if year== 2000 & state=="WV" & candidate=="Denise Giardina"
replace female=1 if year== 2002 & state=="AK" & candidate=="Desa Jacobsson"
replace female=1 if year== 2002 & state=="AZ" & candidate=="D'Herrera Tapia (write-in)"
replace female=1 if year== 2002 & state=="AZ" & candidate=="Diana Kennedy (write-in)"
replace female=1 if year== 2002 & state=="AK" & candidate=="Diane Benson"
replace female=1 if year== 1986 & state=="IL" & candidate=="Diane Roling"
replace female=1 if year== 1982 & state=="NY" & candidate=="Diane Wang"
replace female=1 if year== 1978 & state=="NY" & candidate=="Dianne Feeley"
replace female=1 if year== 1990 & state=="CA" & candidate=="Dianne Feinstein"
replace female=1 if year== 2006 & state=="NV" & candidate=="Dina Titus"
replace female=1 if year== 1980 & state=="WA" & candidate=="Dixy Lee Ray"
replace female=1 if year== 2000 & state=="WV" & candidate=="Donna McCase"
replace female=1 if year== 1979 & state=="KY" & candidate=="Doris Binion"
replace female=1 if year== 1992 & state=="MT" & candidate=="Dorothy Bradley"
replace female=1 if year== 2002 & state=="CA" & candidate=="Edie Bukewihge"
replace female=1 if year== 1986 & state=="CA" & candidate=="Eileen Anderson"
replace female=1 if year== 1990 & state=="CA" & candidate=="Eileen Anderson"
replace female=1 if year== 1998 & state=="MD" & candidate=="Eileen Rehrman"
replace female=1 if year== 1992 & state=="UT" & candidate=="Eleanor Garcia"
replace female=1 if year== 1992 & state=="RI" & candidate=="Elizabeth Anne Leonard"
replace female=1 if year== 1992 & state=="NH" & candidate=="Elizabeth Hager"
replace female=1 if year== 1982 & state=="CA" & candidate=="Elizabeth Martinez"
replace female=1 if year== 1983 & state=="KY" & candidate=="Elizabeth Wickman"
replace female=1 if year== 1978 & state=="CT" & candidate=="Ella Grasso"
replace female=1 if year== 1996 & state=="WA" & candidate=="Ellen Craswell"
replace female=1 if year== 1994 & state=="MD" & candidate=="Ellen Sauerbrey"
replace female=1 if year== 1998 & state=="MD" & candidate=="Ellen Sauerbrey"
replace female=1 if year== 1978 & state=="CO" & candidate=="Elsa Blum"
replace female=1 if year== 1978 & state=="OR" & candidate=="Emily Ashworth"
replace female=1 if year== 1998 & state=="AK" & candidate=="Erica Jacobsson"
replace female=1 if year== 1994 & state=="CT" & candidate=="Eunace Groark"
replace female=1 if year== 1990 & state=="MA" & candidate=="Evelyn F. Murphy"
replace female=1 if year== 1979 & state=="MS" & candidate=="Evelyn Gandy"
replace female=1 if year== 1983 & state=="MS" & candidate=="Evelyn Gandy"
replace female=1 if year== 2004 & state=="NC" & candidate=="Fern Shubert"
replace female=1 if year== 1980 & state=="MT" & candidate=="Florence Haegen"
replace female=1 if year== 2002 & state=="AK" & candidate=="Fran Ulmer"
replace female=1 if year== 1998 & state=="CO" & candidate=="Gail Schoettler"
replace female=1 if year== 2008 & state=="VT" & candidate=="Gaye Symington"
replace female=1 if year== 1982 & state=="CA" & candidate=="Genevieve Marcus"
replace female=1 if year== 1982 & state=="ME" & candidate=="Georgette Berube"
replace female=1 if year== 2002 & state=="AL" & candidate=="Gladys Riddle"
replace female=1 if year== 1994 & state=="CA" & candidate=="Gloria Estela La Riva"
replace female=1 if year== 1998 & state=="CA" & candidate=="Gloria Estela La Riva"
replace female=1 if year== 1992 & state=="ND" & candidate=="H. Elaine Lindgren"
replace female=1 if year== 1990 & state=="MN" & candidate=="Heartwarrior (Judith Chosa)"
replace female=1 if year== 2000 & state=="ND" & candidate=="Heidi Heitkamp, D ag"
replace female=1 if year== 1986 & state=="PA" & candidate=="Heidi Hoover"
replace female=1 if year== 1986 & state=="NE" & candidate=="Helen Boosalis"
replace female=1 if year== 1994 & state=="MD" & candidate=="Helen Delitch Bentley"
replace female=1 if year== 1983 & state=="MS" & candidate=="Helen McMullen Williams"
replace female=1 if year== 1999 & state=="MS" & candidate=="Helen Perkins"
replace female=1 if year== 1980 & state=="MO" & candidate=="Helen Savio"
replace female=1 if year== 1982 & state=="RI" & candidate=="Hilary Salt"
replace female=1 if year== 2002 & state=="CA" & candidate=="Iris Adam"
replace female=1 if year== 1998 & state=="NV" & candidate=="Jan Laverty Jones"
replace female=1 if year== 1994 & state=="NV" & candidate=="Jan Lavety Jones"
replace female=1 if year== 1982 & state=="NY" & candidate=="Jane Benedict"
replace female=1 if year== 1998 & state=="AZ" & candidate=="Jane Dee Hull"
replace female=1 if year== 1986 & state=="TN" & candidate=="Jane Eskind"
replace female=1 if year== 1998 & state=="CA" & candidate=="Jane Harman"
replace female=1 if year== 1996 & state=="DE" & candidate=="Janet C. Rzewnicki"
replace female=1 if year== 2002 & state=="AZ" & candidate=="Janet Napolitano"
replace female=1 if year== 2006 & state=="AZ" & candidate=="Janet Napolitano"
replace female=1 if year== 2002 & state=="FL" & candidate=="Janet Reno"
replace female=1 if year== 2006 & state=="CA" & candidate=="Janice Jordan"
replace female=1 if year== 1982 & state=="HI" & candidate=="Jean King"
replace female=1 if year== 1988 & state=="WA" & candidate=="Jeanne Dixon"
replace female=1 if year== 1996 & state=="NH" & candidate=="Jeanne Shaheen"
replace female=1 if year== 1998 & state=="NH" & candidate=="Jeanne Shaheen"
replace female=1 if year== 2000 & state=="NH" & candidate=="Jeanne Shaheen"
replace female=1 if year== 2000 & state=="MO" & candidate=="Jen Sievers"
replace female=1 if year== 2004 & state=="MO" & candidate=="Jennie Lee Sievers"
replace female=1 if year== 2008 & state=="MO" & candidate=="Jennie Lee Sievers"
replace female=1 if year== 2002 & state=="MI" & candidate=="Jennifer Granholm"
replace female=1 if year== 2006 & state=="MI" & candidate=="Jennifer Granholm"
replace female=1 if year== 1978 & state=="PA" & candidate=="Jennifer Wesner"
replace female=1 if year== 1978 & state=="AZ" & candidate=="Jessica Sampson"
replace female=1 if year== 1990 & state=="IL" & candidate=="Jessie Fields"
replace female=1 if year== 1978 & state=="MN" & candidate=="Jill Lakowske"
replace female=1 if year== 2008 & state=="IN" & candidate=="Jill Long Thompson"
replace female=1 if year== 2002 & state=="MA" & candidate=="Jill Stein"
replace female=1 if year== 2002 & state=="AR" & candidate=="Jimmy Lou Fisher"
replace female=1 if year== 1990 & state=="IA" & candidate=="Jo Ann Zimmerman"
replace female=1 if year== 1990 & state=="KS" & candidate=="Joan Finney"
replace female=1 if year== 1986 & state=="FL" & candidate=="Joan L. Wollin"
replace female=1 if year== 1994 & state=="KS" & candidate=="Joan Wagnon"
replace female=1 if year== 2007 & state=="KY" & candidate=="Jodi Richards"
replace female=1 if year== 2003 & state=="KY" & candidate=="Jody Richards"
replace female=1 if year== 1994 & state=="AK" & candidate=="Jude Henzler"
replace female=1 if year== 1994 & state=="ME" & candidate=="Judith Foss"
replace female=1 if year== 2006 & state=="IL" & candidate=="Judy B. Topinka"
replace female=1 if year== 1996 & state=="MT" & candidate=="Judy Jacobson"
replace female=1 if year== 2000 & state=="MT" & candidate=="Judy Martz"
replace female=1 if year== 1978 & state=="SC" & candidate=="Judy Reynolds"
replace female=1 if year== 1996 & state=="NC" & candidate=="Julia Van Witt"
replace female=1 if year== 1986 & state=="CT" & candidate=="Julie D. Belaga"
replace female=1 if year== 1982 & state=="NV" & candidate=="June Carr"
replace female=1 if year== 2004 & state=="MO" & candidate=="Karen Skelton-Memhardt"
replace female=1 if year== 2001 & state=="NJ" & candidate=="Kari Sachs"
replace female=1 if year== 2002 & state=="MN" & candidate=="Kari Sachs"
replace female=1 if year== 1998 & state=="AZ" & candidate=="Katherine Gallant"
replace female=1 if year== 2006 & state=="AL" & candidate=="Katherine Mack"
replace female=1 if year== 2003 & state=="LA" & candidate=="Kathleen B. Blanco"
replace female=1 if year== 1994 & state=="CA" & candidate=="Kathleen Brown"
replace female=1 if year== 2002 & state=="WI" & candidate=="Kathleen Falk"
replace female=1 if year== 2002 & state=="MD" & candidate=="Kathleen Kennedy Townsend"
replace female=1 if year== 2002 & state=="KS" & candidate=="Kathleen Sebelius"
replace female=1 if year== 2006 & state=="KS" & candidate=="Kathleen Sebelius"
replace female=1 if year== 1992 & state=="WA" & candidate=="Kathleen Wheeler"
replace female=1 if year== 1986 & state=="WI" & candidate=="Kathryn Christenson (LF)"
replace female=1 if year== 1994 & state=="WY" & candidate=="Kathy Karpan"
replace female=1 if year== 1982 & state=="MN" & candidate=="Kathy Wheeler"
replace female=1 if year== 1999 & state=="MS" & candidate=="Katie Perrone"
replace female=1 if year== 2003 & state=="MS" & candidate=="Katie Perrone, D"
replace female=1 if year== 2008 & state=="NH" & candidate=="Katy Forry"
replace female=1 if year== 1986 & state=="NE" & candidate=="Kay A. Orr"
replace female=1 if year== 1990 & state=="NE" & candidate=="Kay Orr"
replace female=1 if year== 2006 & state=="MA" & candidate=="Kerry Healy"
replace female=1 if year== 1982 & state=="AR" & candidate=="Kim Hendren"
replace female=1 if year== 2002 & state=="NY" & candidate=="Kimberly Wilder"
replace female=1 if year== 1988 & state=="UT" & candidate=="Kitty K. Burton"
replace female=1 if year== 1992 & state=="NC" & candidate=="Lacy Thornburg"
replace female=1 if year== 1998 & state=="OK" & candidate=="Laura Boyd"
replace female=1 if year== 1984 & state=="UT" & candidate=="Laura Ferguson"
replace female=1 if year== 1990 & state=="NY" & candidate=="Lenora B. Fulani"
replace female=1 if year== 1994 & state=="NY" & candidate=="Lenora B. Fulani"
replace female=1 if year== 1986 & state=="NY" & candidate=="Lenora Fulani"
replace female=1 if year== 1998 & state=="AL" & candidate=="Lenora Pate"
replace female=1 if year== 2006 & state=="NV" & candidate=="Leola McConnell"
replace female=1 if year== 1986 & state=="OK" & candidate=="Leslie Fisher"
replace female=1 if year== 1998 & state=="HI" & candidate=="Linda Lingle"
replace female=1 if year== 2002 & state=="HI" & candidate=="Linda Lingle"
replace female=1 if year== 2006 & state=="HI" & candidate=="Linda Lingle"
replace female=1 if year== 1992 & state=="UT" & candidate=="Linda Metzger-Agin"
replace female=1 if year== 1982 & state=="CA" & candidate=="Linda Parnell"
replace female=1 if year== 2002 & state=="GA" & candidate=="Linda Schrenko"
replace female=1 if year== 2002 & state=="FL" & candidate=="Lois Frankel"
replace female=1 if year== 1989 & state=="NJ" & candidate=="Lois G. Rand"
replace female=1 if year== 2006 & state=="NV" & candidate=="Lorraine T. Hunt"
replace female=1 if year== 1994 & state=="RI" & candidate=="Louise Durfee"
replace female=1 if year== 1978 & state=="MD" & candidate=="Louise Gore"
replace female=1 if year== 1980 & state=="WA" & candidate=="Louise Saluteen"
replace female=1 if year== 1978 & state=="NH" & candidate=="Lucille Lapinskas"
replace female=1 if year== 2006 & state=="AL" & candidate=="Lucy Baxley"
replace female=1 if year== 1994 & state=="MI" & candidate=="Lynn Jondahl"
replace female=1 if year== 1994 & state=="PA" & candidate=="Lynn Yeakel"
replace female=1 if year== 2006 & state=="CT" & candidate=="M. Jodi Rell, R i"
replace female=1 if year== 1978 & state=="NH" & candidate=="Mabel Everett"
replace female=1 if year== 1982 & state=="VT" & candidate=="Madeleine Kunin"
replace female=1 if year== 1984 & state=="VT" & candidate=="Madeleine Kunin"
replace female=1 if year== 1988 & state=="VT" & candidate=="Madeleine Kunin"
replace female=1 if year== 1986 & state=="VT" & candidate=="Madeleine M. Kunin (D)i"
replace female=1 if year== 1982 & state=="IA" & candidate=="Marcia Farrington"
replace female=1 if year== 1986 & state=="NV" & candidate=="Marcia Joni Wines"
replace female=1 if year== 1996 & state=="MO" & candidate=="Margaret Kelly"
replace female=1 if year== 1978 & state=="WY" & candidate=="Margaret McKinstry"
replace female=1 if year== 1986 & state=="NE" & candidate=="Marge Higgins"
replace female=1 if year== 1990 & state=="PA" & candidate=="Marguerite Luksik"
replace female=1 if year== 1990 & state=="CA" & candidate=="Maria Elizabeth Munoz"
replace female=1 if year== 1984 & state=="VT" & candidate=="Marian Wayner"
replace female=1 if year== 2000 & state=="VT" & candidate=="Marilyn Christian"
replace female=1 if year== 1978 & state=="CA" & candidate=="Marilyn Seals"
replace female=1 if year== 2006 & state=="TN" & candidate=="Marivuana S. Leinoff"
replace female=1 if year== 1990 & state=="FL" & candidate=="Marlene Woodson-Howard"
replace female=1 if year== 1983 & state=="KY" & candidate=="Martha Lane Collins"
replace female=1 if year== 1991 & state=="KY" & candidate=="Martha Wilkinson"
replace female=1 if year== 1994 & state=="ME" & candidate=="Mary Adams"
replace female=1 if year== 1998 & state=="NY" & candidate=="Mary Alice France"
replace female=1 if year== 1996 & state=="VT" & candidate=="Mary Alice Herbert"
replace female=1 if year== 1978 & state=="NY" & candidate=="Mary Anne Krupsek"
replace female=1 if year== 1994 & state=="MD" & candidate=="Mary Boergers"
replace female=1 if year== 2000 & state=="NH" & candidate=="Mary Brown"
replace female=1 if year== 1992 & state=="IN" & candidate=="Mary Catherine Barton"
replace female=1 if year== 1986 & state=="MD" & candidate=="Mary Fellenbaum Holter"
replace female=1 if year== 1986 & state=="AK" & candidate=="Mary Jane O'Brannon"
replace female=1 if year== 1990 & state=="MN" & candidate=="Mary Jane Rachner"
replace female=1 if year== 1995 & state=="LA" & candidate=="Mary Landreau"
replace female=1 if year== 1990 & state=="WY" & candidate=="Mary Mead"
replace female=1 if year== 1980 & state=="WA" & candidate=="Mary Nell Bockman"
replace female=1 if year== 2006 & state=="OR" & candidate=="Mary Starrett, Con"
replace female=1 if year== 1993 & state=="VA" & candidate=="Mary Sue Terry"
replace female=1 if year== 1978 & state=="NY" & candidate=="Mary Sue Tobin"
replace female=1 if year== 2007 & state=="LA" & candidate=="Mary Volentine Smith"
replace female=1 if year== 1992 & state=="MO" & candidate=="MaryJ.Johnson"
replace female=1 if year== 2006 & state=="NY" & candidate=="Maura DeLuca"
replace female=1 if year== 2002 & state=="HI" & candidate=="Mazie Hirono"
replace female=1 if year== 1995 & state=="LA" & candidate=="Melinda Schwegmann"
replace female=1 if year== 2006 & state=="NV" & candidate=="Melody Mimi. Damayo"
replace female=1 if year== 2006 & state=="AK" & candidate=="Merica Hlatcu"
replace female=1 if year== 2000 & state=="WA" & candidate=="Meta Heller"
replace female=1 if year== 1982 & state=="GA" & candidate=="Mildred Glover"
replace female=1 if year== 1986 & state=="NE" & candidate=="Mina B. Dillingham"
replace female=1 if year== 1990 & state=="NH" & candidate=="Miriam F. Luce"
replace female=1 if year== 1992 & state=="NH" & candidate=="Miriam F. Luce"
replace female=1 if year== 2002 & state=="CA" & candidate=="Mosemarie Boyd"
replace female=1 if year== 1994 & state=="AL" & candidate=="Mrs. Frank Steward"
replace female=1 if year== 1994 & state=="RI" & candidate=="Myrth York"
replace female=1 if year== 1998 & state=="RI" & candidate=="Myrth York"
replace female=1 if year== 2002 & state=="RI" & candidate=="Myrth York"
replace female=1 if year== 2002 & state=="AZ" & candidate=="Naida Axford (write-in)"
replace female=1 if year== 1999 & state=="KY" & candidate=="Nailah Jumoke-Yarbrough"
replace female=1 if year== 1986 & state=="NE" & candidate=="Nancy Hoch"
replace female=1 if year== 1982 & state=="NY" & candidate=="Nancy Ross"
replace female=1 if year== 1998 & state=="GA" & candidate=="Nancy Smith Schaefer"
replace female=1 if year== 1993 & state=="VA" & candidate=="Nancy Spanhaus"
replace female=1 if year== 2002 & state=="GA" & candidate=="Nannette Garrett"
replace female=1 if year== 1996 & state=="WA" & candidate=="Nona Brazier"
replace female=1 if year== 1986 & state=="OR" & candidate=="Norma Paulus"
replace female=1 if year== 1990 & state=="WY" & candidate=="Nyla Murphy"
replace female=1 if year== 2004 & state=="UT" & candidate=="Olene Walker"
replace female=1 if year== 1990 & state=="NV" & candidate=="Olga Covelli"
replace female=1 if year== 2006 & state=="MN" & candidate=="Pam Ellison"
replace female=1 if year== 1996 & state=="WA" & candidate=="Pam Roach"
replace female=1 if year== 1994 & state=="ME" & candidate=="Pamela Cahill"
replace female=1 if year== 2004 & state=="VT" & candidate=="Patricia Hejny"
replace female=1 if year== 2002 & state=="VT" & candidate=="Patricia Henjy"
replace female=1 if year== 1998 & state=="ME" & candidate=="Patricia LaMarche"
replace female=1 if year== 2006 & state=="ME" & candidate=="Patricia LaMarche"
replace female=1 if year== 1998 & state=="MA" & candidate=="Patricia McGovern"
replace female=1 if year== 1994 & state=="HI" & candidate=="Patricia Saiki"
replace female=1 if year== 1978 & state=="OH" & candidate=="Patricia Wright"
replace female=1 if year== 1986 & state=="HI" & candidate=="Patsy T. Mink"
replace female=1 if year== 1998 & state=="OR" & candidate=="Patti Steurer"
replace female=1 if year== 1986 & state=="NV" & candidate=="Patty Cafferata"
replace female=1 if year== 1994 & state=="CT" & candidate=="Pauline Kezer"
replace female=1 if year== 1994 & state=="PA" & candidate=="Peg Luksik"
replace female=1 if year== 1998 & state=="PA" & candidate=="Peg Luksik"
replace female=1 if year== 1990 & state=="HI" & candidate=="Peggy Ha'o Ross"
replace female=1 if year== 1999 & state=="KY" & candidate=="Peppy Martin"
replace female=1 if year== 1982 & state=="OH" & candidate=="Phyllis Goetz"
replace female=1 if year== 1998 & state=="CA" & candidate=="Pia Jensen"
replace female=1 if year== 1990 & state=="ID" & candidate=="Rachel S. Gilbert"
replace female=1 if year== 1990 & state=="TX" & candidate=="Ray Rachal"
replace female=1 if year== 2003 & state=="KY" & candidate=="Rebecca Jackson"
replace female=1 if year== 1982 & state=="MA" & candidate=="Rebecca Shipman"
replace female=1 if year== 2002 & state=="SC" & candidate=="Rebekah Sutherland"
replace female=1 if year== 1992 & state=="UT" & candidate=="Rita Gum"
replace female=1 if year== 1998 & state=="CT" & candidate=="Roberta Scaglione TLC"
replace female=1 if year== 1981 & state=="NJ" & candidate=="Rose Monyek"
replace female=1 if year== 1982 & state=="IA" & candidate=="Roxanne Conlin"
replace female=1 if year== 1984 & state=="NC" & candidate=="Ruby Hooper"
replace female=1 if year== 1992 & state=="NC" & candidate=="Ruby Thompson Hooper"
replace female=1 if year== 2000 & state=="DE" & candidate=="Ruth Ann Minner"
replace female=1 if year== 2004 & state=="DE" & candidate=="Ruth Ann Minner"
replace female=1 if year== 2004 & state=="WA" & candidate=="Ruth Bennett"
replace female=1 if year== 1998 & state=="VT" & candidate=="Ruth Dwyer"
replace female=1 if year== 2000 & state=="VT" & candidate=="Ruth Dwyer"
replace female=1 if year== 1996 & state=="MO" & candidate=="Ruth Redel"
replace female=1 if year== 1992 & state=="WA" & candidate=="Sally McQuown"
replace female=1 if year== 1998 & state=="CO" & candidate=="Sandra Johnson"
replace female=1 if year== 1978 & state=="TX" & candidate=="Sara Jean Johnston"
replace female=1 if year== 2004 & state=="WV" & candidate=="Sarah Minear"
replace female=1 if year== 2006 & state=="AK" & candidate=="Sarah Palin"
replace female=1 if year== 2008 & state=="MO" & candidate=="Sarah Steelman"
replace female=1 if year== 2002 & state=="MA" & candidate=="Shannon O'Brien"
replace female=1 if year== 1992 & state=="MO" & candidate=="SharonRogers"
replace female=1 if year== 1986 & state=="TX" & candidate=="Sheila Bilyea"
replace female=1 if year== 1994 & state=="IL" & candidate=="Sheila Jones"
replace female=1 if year== 1986 & state=="ME" & candidate=="Sherry F. Huber"
replace female=1 if year== 1982 & state=="ME" & candidate=="Sherry Huber"
replace female=1 if year== 1998 & state=="TN" & candidate=="Shirely Beck-Vosse"
replace female=1 if year== 2002 & state=="NV" & candidate=="Shirley Cook"
replace female=1 if year== 1996 & state=="VT" & candidate=="Stacy Hever"
replace female=1 if year== 1981 & state=="NJ" & candidate=="Stella Mann"
replace female=1 if year== 1994 & state=="TN" & candidate=="Stephanie Holt"
replace female=1 if year== 1997 & state=="VA" & candidate=="Sue DeBauche"
replace female=1 if year== 2006 & state=="MN" & candidate=="Sue Jeffers"
replace female=1 if year== 1994 & state=="KS" & candidate=="Susan Briggs"
replace female=1 if year== 1998 & state=="TX" & candidate=="Susan Lee Solar"
replace female=1 if year== 1994 & state=="ME" & candidate=="Susan M. Collins"
replace female=1 if year== 1994 & state=="NV" & candidate=="Suzanne Nounna"
replace female=1 if year== 1994 & state=="AK" & candidate=="Sybil Skelton-Monroe"
replace female=1 if year== 1998 & state=="AK" & candidate=="Sylvia Sullivan"
replace female=1 if year== 1990 & state=="CO" & candidate=="Tea Shook"
replace female=1 if year== 1979 & state=="KY" & candidate=="Thelma Stovall"
replace female=1 if year== 1978 & state=="CA" & candidate=="Theresa Dietrich"
replace female=1 if year== 1986 & state=="TX" & candidate=="Theresa Doyle"
replace female=1 if year== 1990 & state=="TX" & candidate=="Theresa Hearn-Haynes"
replace female=1 if year== 1978 & state=="HI" & candidate=="Valentine Huihui"
replace female=1 if year== 1978 & state=="HI" & candidate=="Valentine Wessel"
replace female=1 if year== 1994 & state=="IA" & candidate=="Veronica Wells Butler"
replace female=1 if year== 1994 & state=="OK" & candidate=="Virginia Hale"
replace female=1 if year== 1986 & state=="OK" & candidate=="Virginia Jenner"
replace female=1 if year== 1984 & state=="IN" & candidate=="Virginia McCarty"
replace female=1 if year== 1982 & state=="TN" & candidate=="Virginia Nyabongo"
replace female=1 if year== 1994 & state=="TN" & candidate=="Virginia Nyabongo"
replace female=1 if year== 1998 & state=="TN" & candidate=="Virginia Nyaboongo"
replace female=1 if year== 2006 & state=="IA" & candidate=="Wendy Barth"
replace female=1 if year== 1990 & state=="MN" & candidate=="Wendy Lyons"
replace female=1 if year== 1998 & state=="OH" & candidate=="Zanna Feitler"
replace female=0 if female==.


/*Creating a general vote variable*/
/*Note: I force all vote shares below 20% to 0.*/
replace genvote=0 if genvote==.
replace genvot=0 if genvot==.
replace generalvote=0 if generalvote==.
gen general_vote=genvote+genvot+generalvote
replace general_vote=. if general_vote==0
drop  genvot genvote generalvote

/*I'm missing data on a few elections. I transcribe it here*/
replace general_vote=62.4 if year==1983 & state=="LA" & candidate=="Edwin Edwards"
replace general_vote=36.3 if year==1983 & state=="LA" & candidate=="David Treen"
replace general_vote=45.4 if year==1984 & state=="NC" & candidate=="Rufus Edmisten"
replace general_vote=8.8 if year==1987 & state=="LA" & candidate=="Jim Brown"
replace general_vote=9.9 if year==1987 & state=="LA" & candidate=="W.J. Billy Tauzin"
replace general_vote=18.5 if year==1987 & state=="LA" & candidate=="Robert Livingston"
replace general_vote=28 if year==1987 & state=="LA" & candidate=="Edwin Edwards"
replace general_vote=33.1 if year==1987 & state=="LA" & candidate=="Buddy Roemer"
replace general_vote=30.9 if year==1998 & state=="NH" & candidate=="Jay Lucas"
replace general_vote=66.1 if year==1998 & state=="NH" & candidate=="Jeanne Shaheen"
replace general_vote=54.3 if year==1998 & state=="NY" & candidate=="George Pataki"
replace general_vote=40.9 if year==1998 & state=="OK" & candidate=="Laura Boyd"
replace general_vote=57.9 if year==1998 & state=="OK" & candidate=="Frank Keating"
replace general_vote=29.5 if year==1999 & state=="LA" & candidate=="William Jefferson"
replace general_vote=62.2 if year==1999 & state=="LA" & candidate=="Mike Foster (see footnote b)"
replace general_vote=9.6 if year==2006 & state=="ME" & candidate=="Patricia LaMarche"
replace general_vote=21.6 if year==2006 & state=="ME" & candidate=="Barbara Merrill"
replace general_vote=30.2 if year==2006 & state=="ME" & candidate=="Chandler Woodcock"
replace general_vote=38.1 if year==2006 & state=="ME" & candidate=="John Baldacci"
replace general_vote=. if year==2006 & state=="WY" & candidate=="Al Hamburg"
replace general_vote=. if year==2006 & state=="WY" & candidate=="John Self"
replace general_vote=42.1 if year==1998 & state=="AL" & candidate=="Fob James"
replace general_vote=. if year==1998 & state=="AL" & candidate=="Guy Hunt"
replace general_vote=12.5 if year==2007 & state=="LA" & candidate=="Foster Campbell"
replace general_vote=14.4 if year==2007 & state=="LA" & candidate=="John Georges"
replace general_vote=17.5 if year==2007 & state=="LA" & candidate=="Walter Boasso"
replace general_vote=53.9 if year==2007 & state=="LA" & candidate=="Bobby Jindal"

/*Generate general vote sub 20 flag*/
gen general_vote_sub20=0
replace general_vote_sub20=1 if general_vote>0 & general_vote<20
label variable general_vote_sub20 "Dummy for whether the general election vote share was under 20 (and forced to zero using my methodology)"
gen general_vote_raw=general_vote
replace general_vote=0 if general_vote<20
label variable general_vote_raw "The unedited general election vote share for a candidate, as reported in the data"


/*Creates a general candidate dummy*/
gen gen_cand=1
replace gen_cand=0 if general_vote<20 | general_vote==.
label variable gen_cand "Dummy for candidates that appeared in the general election"

/*Creates open election variable*/
gen incumbxgenvote=incumbent*general_vote
sort year state
by year state: egen incumbent_in_general=max(incumbxgenvote)
replace incumbent_in_general=1 if incumbent_in_general>0
replace incumbent_in_general=0 if incumbent_in_general==.
replace incumbent_in_general=0 if incumbent==0
gen open=0
by year state: egen g=max(incumbent_in_general)
replace open=1 if g==0
gen open_pri=0
sort year state party
by year state party: egen h=max(incumbent)
replace open_pri=1 if h==0
drop incumbxgenvote g h
label variable incumbent_in_general "Dummy for an incumbent candidate who makes it to the general election"
label variable open_pri "Dummy for an open primary election (i.e. no incumbents running)"

/*Create a time and time squared variable*/
gen t=year-1976
gen tsquared=t^2
label variable t "Time variable, with t_1=1977"
label variable tsquared "Time variable squared"
gen txfem=t*female

/*Create a challenger dummy*/
gen challenger=1
replace challenger=0 if incumbent_in_general==1 | open==1 

/*Create a primary candidate count variable (i.e., number of candidates in a given party primary)*/
sort year state party
by year state party: gen n_dpri_cand=_N if party=="D"
by year state party: gen n_rpri_cand=_N if party=="R"
/*Note that I don't do this for third party candidates, since it's likely that they did not face in the same primary (e.g. Liberatarian and Green)*/

/*Create a dummy for candidates who won the general election*/
gen won_general=0
sort year state
by year state: egen x=max(general_vote)
by year state: replace won_general=1 if x==general_vote
drop x
replace won_general=0 if year==1982 & state=="IL" & candidate=="Adlai Stevenson, II    "

/*Order and label the variables*/
label variable year "Year of election"
label variable state "State of election"
label variable candidate "Candidate's name"
label variable female "Dummy for a female candidate"
label variable party "Candidate's party"
label variable prev_occ "Candidate's previous job. Refer to the codebook for more detail"
label variable _primary_spend_real "Amount candidate spent in the primary election, in 2009 USD"
label variable primary_vote "Candidate's vote share in primary election"
label variable _primary_spend_r_real "Amount candidate spent in the second primary election, if there was one, in 2009 USD"
label variable primary_vote_r "Candidate's vote share in the second primary election, if there was one"
label variable _general_spend_real "Amount candidate spent in the general election, in 2009 USD"
label variable general_vote "Candidate's vote share in the general election"
label variable _total_spend_real "Amount candidate spent in both the primary and general elections, in 2009 USD"
label variable runoff_vote "Candidate's vote share the runoff election, if there was one"
label variable _runoff_spend_real "Amount candidate spent in the runoff election, if there was one in 2009 USD"
label variable democrat "Dummy for a Democrat candidate"
label variable republican "Dummy for a Republican candidate"
label variable third_party "Dummy for a third party candidate"
label variable incumbent "Dummy for an incumbent candidate"
label variable open "Dummy for an open general election (i.e. no incumbents running)"
label variable pubfnc "Dummy for some type of public campaign finance law in effect"
label variable runoff_spend_nom "Amount candidate spent in the runoff election, if there was one, in nominal terms"
label variable primary_spend_nom "Amount candidate spent in the primary election, in nominal terms"
label variable primary_spend_r_nom "Amount candidate spent in the second primary election, if there was one, in nominal terms"
label variable general_spend_nom "Amount candidate spent in the general election, in nominal terms"
label variable total_spend_nom "Amount candidate spent in both the primary and general elections, in 2009 USD"
label variable n_dpri_cand "Number of Democratic primary election candidates"
label variable n_rpri_cand "Number of Republican primary election candidates"
label variable lnprimary_spend_real "Log amount candidate spent in the primary election, in 2009 USD"
label variable lnprimary_spend_r_real "Log amount candidate spent in the second primary election, if there was one, in 2009 USD"
label variable lngeneral_spend_real "Log amount candidate spent in the general election, in 2009 USD"
label variable lnrunoff_spend_real "Log amount candidate spent in the runoff election, if there was one in 2009 USD"
label variable lntotal_spend_real "Log amount candidate spent in the runoff election, if there was one in 2009 USD"
label variable challenger "Dummy for a general election candidate facing an incumbent"
label variable txfem "Interaction for time and female variables"
label variable won_general "Dummy for a candidate who won the general election"

/*Creates a variable measuring the percentage of females in the primary*/
sort year state party
by year state party: egen pct_pri_fem=mean(female) if female !=-9
by year state party: egen n_femcand_pri=total(female) if female !=-9
replace pct_pri_fem=100*pct_pri_fem
/*I have to drop the observations for 3rd party candidates, since it is likely that this umbrella term groups
together candidates from various parties*/
replace pct_pri_fem=. if party=="3rd/Ind."
replace n_femcand_pri=. if party=="3rd/Ind."
label variable pct_pri_fem "Percentage of females in a given candidate's primary"
label variable n_femcand_pri "Number of females in a given candidate's primary"

/*Reduces clutter by dropping some spending variables*/
drop lnprimary_spend_real _primary_spend_real lnprimary_spend_r_real _primary_spend_r_real lngeneral_spend_real _general_spend_real lnrunoff_spend_real _runoff_spend_real runoff_spend_nom total_spend_nom general_spend_nom primary_spend_r_nom primary_spend_nom

/*Create marker*/
sort state year
by state year: gen marker=1 if _n==1
sort year state party
by year state party: gen pri_marker=1 if _n==1
label variable pri_marker "=1 if candidate is first observation for party election year"

/*Create dummies for gender and party interactions*/
gen gfr=1 if party=="R" & female==1 & gen_cand==1
gen gmr=1 if party=="R" & female==0 & gen_cand==1
gen gfd=1 if party=="D" & female==1 & gen_cand==1
gen gmd=1 if party=="D" & female==0 & gen_cand==1
foreach i in gfr gmr gfd gmd{
replace `i'=0 if `i'==.
}

/*Calculates number of candidates in general election, by party and gender*/
sort year state
*by year state: egen efr=total(gfr) 
*by year state: egen efd=total(gfd)
*by year state: egen emr=total(gmr)
*by year state: egen emd=total(gmd)

/*label variables*/
label variable marker "=1 if candidate is the first observation for election year"
label variable gfr "=1 if female, republican, and general election candidate"
label variable gmr "=1 if male, republican, and general election candidate"
label variable gfd "=1 if female, democrat, and general election candidate"
label variable gmd "=1 if male, democrat, and general election candidate"
*label variable efr "Total number of female, republican, general election candidates"
*label variable efd "Total number of female, democrat, general election candidates"
*label variable emr "Total number of male, republican, general election candidates"
*label variable emd "Total number of male, democrat, general election candidates"

/*Generates female vote share variable*/
gen i=female*general_vote
by year state: egen femgen_vote=max(i)
drop i
replace femgen_vote=. if femgen_vote==0
label variable femgen_vote "The MAXIMUM female vote share in a given general election."

/*Drops the runoff_vote data*/
drop runoff_vote

/*Reweight all candidates's vote share to be out of 100. E.g. 2 
candidate both receiving 45% of the vote share would be reweighted to 
50%*/
sort year state
by year state: egen general_sum=total(general_vote)
by year state: gen reweight=100*general_vote/general_sum
label variable reweight "Candidate's reweighted general vote share, after dropping candidates getting under 20% and standardizing remaining vote shares"


/*Generate vote share bins*/
gen vsbin=.
forval i=5(5)100{
replace vsbin=`i' if reweight>=`i' & reweight<`i'+5
}
label variable vsbin "Bins that group general vote shares into widths of 5 points"

/*Generate public finance, incumbent, and female interaction terms*/
gen pi=pubfnc*incumbent 
gen PFXFEM=pubfnc*female
label variable pi "Interaction term denoting incumbents in elections where public funding was available"

/*Generate dummy for states that switch public campaign finance laws*/
sort state
by state:egen p=mean(pubfnc)
gen pfswitch=0
replace pfswitch=1 if p>0 & p<1
label variable pfswitch "Dummy for states that changed their public campaign finance laws between 1977-2009"

/*Generate time, state, and state & time dummies for fixed effects*/
tab t, gen(td)
tab state, gen(sd)
forval i = 1/50{
gen tdxsd`i'=sd`i'*t
}
sort state
by state: egen meanpf=mean(pubfnc)

/*Generate open and female interaction terms*/
gen openfem=open*female

/*Generate type of election dummy*/
gen full=0
replace full=1 if state=="AZ" & pubfnc==1
replace full=1 if state=="ME" & pubfnc==1
replace full=1 if state=="VT" & pubfnc==1
label variable full "Dummy for states that provide full campaign finance"
gen partial=0
replace partial=1 if pubfnc==1 & state=="FL"
replace partial=1 if pubfnc==1 & state=="HI"
replace partial=1 if pubfnc==1 & state=="KY"
replace partial=1 if pubfnc==1 & state=="MA"
replace partial=1 if pubfnc==1 & state=="MT"
replace partial=1 if pubfnc==1 & state=="NE"
replace partial=1 if pubfnc==1 & state=="MD"
replace partial=1 if pubfnc==1 & state=="MI"
replace partial=1 if pubfnc==1 & state=="MN"
replace partial=1 if pubfnc==1 & state=="NJ"
replace partial=1 if pubfnc==1 & state=="RI"
replace partial=1 if pubfnc==1 & state=="WI"
label variable partial "Dummy for state that provide partial campaign finance"


/*Generate male incumbent and female incumbent dummies*/
gen m=0
replace m=1 if incumbent_in_general==1 & female==0
gen f=female*incumbent_in_general
sort year state
by year state: egen minc=max(m)
by year state: egen finc=max(f)
label variable minc "Dummy for a male incumbent in a general election"
label variable finc "Dummy for a female incumbent in a general election"

sort year state
by year state: gen fig=1 if femgen_vote>=5 & femgen_vote !=.

drop m f openfem meanpf p PFXFEM general_sum n_rpri n_dpri txfem

/*Generate female party dummies by election*/
foreach i in gfd gfr{
sort year state
by year state: egen _`i'=max(`i')
drop `i'
rename _`i' `i'
}
label variable gfd "=1 if general election features a female democrat"
label variable gfr "=1 if general election features a female republican"


save appended.dta, replace
