clear
set mem 100m
set more off
  
  ////////////////////////////////////////////////////////
 /*Converts .csv files into Stata format and saves them*/
////////////////////////////////////////////////////////


***************************************************************************************
*My import has multiple steps (insheet, outsheet, then insheet again) because I
*need to drop the first observation of every .csv file. It's a title like "1984
*Gubernatorial Data" that messes up my variable names in Stata. So I import the files, drop
*the first observation, outsheet it, then insheet it with the correct column headers.
***************************************************************************************
*Also note that I have several different loops for different years. This is intentional.
*The "general vote" variable is named differently based on the year of the dataset. When
*I append the files (later on; see merge.do) without first destringing this variable, it 
*sometimes gets dropped. So I destring it in the import (i.e. before the append) so when 
*I do append, the general vote variable isn't lost.
***************************************************************************************



foreach i in 1977 1979 1981 1982 1983 1984 1985 1986 1987 1988 1989 1990 1992 1993 1995 1996 1997 1998 1999 2000 2001 2002 2004 2005 2006 2007 2008 2009{
clear
insheet using `i'$.csv
drop in 1/1
outsheet using `i'_outsheeted.csv, comma nonames replace
clear
insheet using `i'_outsheeted.csv, names
gen year=`i'
capture destring pr1, ignore("," "$") force replace
capture destring pr1vote, force replace
capture destring gen, ignore("," "$") force replace
capture destring total, ignore("," "$") force replace
capture destring genvot, force replace
capture destring pr2, ignore("," "$") force replace
capture destring v13, ignore("," "$") force replace
capture destring primaryspent, ignore("," "$") force replace
capture destring generalspent, ignore("," "$") force replace
capture destring totalspent, ignore("," "$") force replace
capture destring primaryvote, force replace

/*Creating a primary vote variable*/
capture gen primary_vote=pr1vote
capture gen primary_vote=p1vote
capture gen primary_vote=primaryvote

/*Creating a primary spend variable*/
capture gen primary_spend_nom=pr1
capture gen primary_spend_nom=p1
capture gen primary_spend_nom=primaryspent

/*Creating a primary runoff vote variable*/
capture gen primary_vote_r=pr2vote 
capture gen primary_vote_r=p2vote

/*Creating a primary runoff spend variable*/
capture gen primary_spend_r_nom=pr2
capture gen primary_spend_r_nom=p2

/*Creating a previous job variable*/
capture gen prev_occ=job
capture gen prev_occ=occupation

/*Creating a general spend variable*/
capture gen general_spend_nom=generalspent
capture gen general_spend_nom=gen

/*Creating a candidate variable*/
capture gen c=candidate7
capture gen c=cand
capture gen c=candidate

/*Creating a total spend variable*/
capture gen total_spend_nom=total
capture gen total_spend_nom=totalspent

save `i'.dta, replace
}


foreach i in 1978 1980 1991 1994 2003{
clear
insheet using `i'$.csv
drop in 1/2
outsheet using `i'_outsheeted.csv, comma nonames replace
clear
insheet using `i'_outsheeted.csv, names
gen year=`i'
capture destring p1, ignore("," "$") force replace
capture destring p1vote, force replace
capture destring p2vote, force replace
capture destring gen, ignore("," "$") force replace
capture destring total, ignore("," "$") force replace
capture destring genvote, force replace
capture destring pr1, ignore("," "$") force replace
capture destring pr1vote, force replace
capture destring runoff, ignore("," "$")  force replace
capture destring pr2, ignore("," "$") force replace
capture destring genvot, force replace
capture destring primaryspent, ignore("," "$") force replace
capture destring generalspent, ignore("," "$") force replace
capture destring totalspent, ignore("," "$") force replace
capture destring primaryvote, force replace

/*Creating a primary vote variable*/
capture gen primary_vote=pr1vote
capture gen primary_vote=p1vote
capture gen primary_vote=primaryvote

/*Creating a primary spend variable*/
capture gen primary_spend_nom=pr1
capture gen primary_spend_nom=p1
capture gen primary_spend_nom=primaryspent

/*Creating a primary runoff vote variable*/
capture gen primary_vote_r=pr2vote 
capture gen primary_vote_r=p2vote

/*Creating a primary runoff spend variable*/
capture gen primary_spend_r_nom=pr2
capture gen primary_spend_r_nom=p2

/*Creating a previous job variable*/
capture gen prev_occ=job
capture gen prev_occ=occupation

/*Creating a general spend variable*/
capture gen general_spend_nom=generalspent
capture gen general_spend_nom=gen

/*Creating a candidate variable*/
capture gen c=candidate7
capture gen c=cand
capture gen c=candidate

/*Creating a total spend variable*/
capture gen total_spend_nom=total
capture gen total_spend_nom=totalspent

save `i'.dta, replace
}

